from flask import json, jsonify
from werkzeug.exceptions import HTTPException


class APIException(HTTPException):
    code = 500
    service_code = None
    message = 'Internal Server Error'

    def __str__(self):
        resp = json.dumps({
            "code": self.code,
            "service_code": self.service_code,
            "message": self.message,
        })
        return resp

    def __init__(self, msg=None, code=None, scode=None):
        if code:
            self.code = code
        if scode:
            self.service_code = scode
        if msg:
            self.message = msg
            
        super(APIException, self).__init__(msg, None)

    def get_body(self, environ=None):
        body = dict(message=self.message, data={}, code= self.service_code)
        text = json.dumps(body)
        return text

    def get_headers(self, environ=None):
        return [('Content-Type', 'application/json')]



# -*- coding: utf-8 -*-
"""
    core.views
    ~~~~~~~~~~~~~~
    项目的演示代码.
    :copyright: (c) 2019-10-08 by datochan.
"""
from quick_flask import quick_flask


@quick_flask.route('/', methods=['GET', 'POST'])
def index():
    return 'Hello, It Works!'



"""
    core.lib.extensions
    ~~~~~~~~~~~~~~
    项目的扩展模块, 如果有新的扩展可在这里添加集中导入.

    :copyright: (c) 2019-10-08 by datochan.
"""
from flask_login import LoginManager
from flask_sqlalchemy import SQLAlchemy

__all__ = ['db', 'login_manager']

db = SQLAlchemy()
login_manager = LoginManager()


"""
    setup
    ~~~~~~~~~~~~~~
    项目的安装文件.

    :copyright: (c) 2019-10-08 by datochan.
"""
from setuptools import setup, find_packages

setup(
    author="datochan",
    author_email="datochan@qq.com",
    description="An python3 flask web framework template.",
    install_requires=[
        "Flask==1.1.1",
        "Flask-HTTPAuth==3.3.0",
        "Flask-Login==0.4.1",
        "Flask-Migrate==2.5.2",
        "Flask-Principal==0.4.0",
        "Flask-Script==2.0.6",
        "Flask-Security==3.0.0",
        "Flask-SQLAlchemy==2.4.1",
        "PyMySQL==0.9.3",
        "SQLAlchemy==1.3",
    ],
    license="MIT",
    name='python-flask-quick-start',
    packages=find_packages(),
    version='1.0',
)
